summaryrefslogtreecommitdiff
path: root/qadevOOo/tests/java/ifc/sdbcx/_XRowLocate.java
diff options
context:
space:
mode:
Diffstat (limited to 'qadevOOo/tests/java/ifc/sdbcx/_XRowLocate.java')
-rw-r--r--qadevOOo/tests/java/ifc/sdbcx/_XRowLocate.java16
1 files changed, 8 insertions, 8 deletions
diff --git a/qadevOOo/tests/java/ifc/sdbcx/_XRowLocate.java b/qadevOOo/tests/java/ifc/sdbcx/_XRowLocate.java
index 5c6903b54513..0886cf7a6da4 100644
--- a/qadevOOo/tests/java/ifc/sdbcx/_XRowLocate.java
+++ b/qadevOOo/tests/java/ifc/sdbcx/_XRowLocate.java
@@ -65,7 +65,7 @@ public class _XRowLocate extends MultiMethodTest {
try {
bookmark1 = oObj.getBookmark() ;
} catch (SQLException e) {
- log.println("Exception occured :" + e) ;
+ log.println("Exception occurred :" + e) ;
}
tRes.tested("getBookmark()", bookmark1 != null) ;
@@ -86,7 +86,7 @@ public class _XRowLocate extends MultiMethodTest {
* </ul> <p>
* Has OK status difference between positions of bookmarks (where
* cursor was moved to and created new one) equals to 0 and no
* exceptions occured, FAILED otherwise.
*/
public void _moveToBookmark() {
requiredMethod("getBookmark()") ;
@@ -101,7 +101,7 @@ public class _XRowLocate extends MultiMethodTest {
}
comparison = oObj.compareBookmarks(bookmark1, tmpBookmark) ;
} catch (SQLException e) {
- log.println("Exception occured :" + e) ;
+ log.println("Exception occurred :" + e) ;
}
tRes.tested("moveToBookmark()", comparison == 0) ;
@@ -115,7 +115,7 @@ public class _XRowLocate extends MultiMethodTest {
* <ul>
* <li> <code>getBookmark()</code> : to have a bookmark to move to.</li>
* </ul> <p>
* Has OK status if no exceptions occured while method call.
*/
public void _moveRelativeToBookmark() {
requiredMethod("getBookmark()") ;
@@ -127,7 +127,7 @@ public class _XRowLocate extends MultiMethodTest {
bookmark2 = oObj.getBookmark() ;
}
} catch (SQLException e) {
- log.println("Exception occured :" + e) ;
+ log.println("Exception occurred :" + e) ;
result = false ;
}
@@ -155,7 +155,7 @@ public class _XRowLocate extends MultiMethodTest {
comparison = oObj.compareBookmarks(bookmark1, bookmark2) ;
comparison1 = oObj.compareBookmarks(bookmark1, bookmark1) ;
} catch (SQLException e) {
- log.println("Exception occured :" + e) ;
+ log.println("Exception occurred :" + e) ;
}
if (comparison != -1) {
@@ -183,7 +183,7 @@ public class _XRowLocate extends MultiMethodTest {
try {
res = oObj.hasOrderedBookmarks() ;
} catch (SQLException e) {
- log.println("Exception occured :" + e) ;
+ log.println("Exception occurred :" + e) ;
result = false ;
}
@@ -219,7 +219,7 @@ public class _XRowLocate extends MultiMethodTest {
result = hash1 != hash2 ;
} catch (SQLException e) {
- log.println("Exception occured :" + e) ;
+ log.println("Exception occurred :" + e) ;
result = false ;
}
@@ -86,7 +86,7 @@ public class _XRowLocate extends MultiMethodTest {
* Has OK status difference between positions of bookmarks (where
* cursor was moved to and created new one) equals to 0 and no
- * exceptions occured, FAILED otherwise.
+ * exceptions occurred, FAILED otherwise.
*/
public void _moveToBookmark() {
@@ -115,7 +115,7 @@ public class _XRowLocate extends MultiMethodTest {
* <li> <code>getBookmark()</code> : to have a bookmark to move to.</li>
* </ul> <p>
- * Has OK status if no exceptions occured while method call.
+ * Has OK status if no exceptions occurred while method call.
*/
public void _moveRelativeToBookmark() {